emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] elpa/scala-mode cb3f278 086/217: Update for marmalade / melpa p


From: ELPA Syncer
Subject: [nongnu] elpa/scala-mode cb3f278 086/217: Update for marmalade / melpa package.
Date: Sun, 29 Aug 2021 11:30:49 -0400 (EDT)

branch: elpa/scala-mode
commit cb3f27815d9eded16a8018d7d8ffc352a57aedb0
Author: Gary Pamparà <gpampara@gmail.com>
Commit: Heikki Vesalainen <heikkivesalainen@yahoo.com>

    Update for marmalade / melpa package.
    
    Signed-off-by: Gary Pamparà <gpampara@gmail.com>
---
 Makefile                                           | 15 ++---
 README.md                                          | 69 +++++++++++++++++-----
 scala-mode-fontlock.el => scala-mode2-fontlock.el  |  4 +-
 scala-mode-indent.el => scala-mode2-indent.el      |  6 +-
 scala-mode-lib.el => scala-mode2-lib.el            |  2 +-
 scala-mode-map.el => scala-mode2-map.el            |  4 +-
 ...a-mode-paragraph.el => scala-mode2-paragraph.el |  2 +-
 scala-mode2-pkg.el                                 |  2 +
 scala-mode-syntax.el => scala-mode2-syntax.el      |  2 +-
 scala-mode.el => scala-mode2.el                    | 34 ++++++-----
 10 files changed, 92 insertions(+), 48 deletions(-)

diff --git a/Makefile b/Makefile
index 3719764..9288123 100644
--- a/Makefile
+++ b/Makefile
@@ -22,13 +22,14 @@ ELISP_OPTIONS           += -L $(ROOT)
 ELISP_OPTIONS          += -f batch-byte-compile
 
 
-ELISP_FILES            += scala-mode-lib
-ELISP_FILES            += scala-mode
-ELISP_FILES            += scala-mode-syntax
-ELISP_FILES            += scala-mode-indent
-ELISP_FILES            += scala-mode-paragraph
-ELISP_FILES            += scala-mode-fontlock
-ELISP_FILES            += scala-mode-map
+ELISP_FILES            += scala-mode2-lib
+ELISP_FILES            += scala-mode2
+ELISP_FILES            += scala-mode2-syntax
+ELISP_FILES            += scala-mode2-indent
+ELISP_FILES            += scala-mode2-paragraph
+ELISP_FILES            += scala-mode2-fontlock
+ELISP_FILES            += scala-mode2-map
+ELISP_FILES            += scala-mode2-pkg
 
 ELISP_SOURCES          += $(ELISP_FILES:%=$(SOURCE_DIR)/%.el)
 
diff --git a/README.md b/README.md
index 1008073..e2f0d9b 100644
--- a/README.md
+++ b/README.md
@@ -18,20 +18,59 @@ standard emacs motions work ofcourse.
 The mode has been developed on 24.2 and uses features not available
 in emacs prior to version 24.
 
-2. Download the files to a local directory. You can use the *git clone*
-command, this will create a new directory called scala-mode2.
-```
-git clone git://github.com/hvesalai/scala-mode2.git
-```
-
-3. Include the following in your `.emacs`  file. If you have been
-using the old scala-mode, make sure it is no longer in *load-path*.
-```
-(add-to-list 'load-path "/path/to/scala-mode2/")
-(require 'scala-mode)
-```
-
-4. That's it. Next you can start emacs and take a look at the
+2. There are two mechanisms that can be used for the installation of
+the mode into Emacs. The preferred manner is to use the built-in
+package manager of Emacs 24 (i.e. `package.el`) and
+the other is to manually clone the git repository, add the path to the mode
+to the load-path and then to require it. For more information regarding
+`package.el` please refer to the [EmacsWiki](http://emacswiki.org/emacs/ELPA).
+
+    1. Package.el:
+        Using the package.el within Emacs installation is the recommended
+        manner to install scala-mode2 as it allows for continuous, easy
+        updating from within Emacs itself. Adding the MELPA
+        repository to your emacs initialization will be required to locate
+        the packages.
+       
+        Add the following to your emacs config (.emacs, init.el, etc),
+        if such a definition already exists, ensure that it contains
+        the MELPA declaration
+
+        ```
+        (add-to-list 'package-archives
+                     '("melpa" . "http://melpa.milkbox.net/packages/";) t)
+        ```
+
+        Once the location of the package repository has been added to your
+        Emacs config, simply navigate to the package view within Emacs, or use
+        `M-x package-list-packages` to list the available packages.
+        Mark the package `scala-mode2` and execute the actions (`X`) to install
+        the mode.
+
+        The remaining config that is required is to edit the Emacs config
+        to activate the mode:
+
+        ```
+        (require 'scala-mode2)
+        ```
+
+    2. Manual:
+        Download the files to a local directory. You can use the *git clone*
+        command, this will create a new directory called scala-mode2.
+
+        ```
+        git clone git://github.com/hvesalai/scala-mode2.git
+        ```
+
+        Include the following in your Emacs config file. If you have been
+        using the old scala-mode, make sure it is no longer in *load-path*.
+
+        ```
+        (add-to-list 'load-path "/path/to/scala-mode2/")
+        (require 'scala-mode2)
+        ```
+
+3. That's it. Next you can start emacs and take a look at the
 customization menu for scala-mode (use **M-x** *customize-mode* when
 in scala-mode or use **M-x** *customize-variable* to customize one
 variable). Also be sure to check the customization tips on various
@@ -395,6 +434,6 @@ Contributors and valuable feedback:
 - Ray Racine
 - Eiríkr Åsheim (aka Erik Osheim)
 - Seth Tisue
-- Gary Pamparà 
+- Gary Pamparà
 - Evan Meagher
 - Andrew Jones
diff --git a/scala-mode-fontlock.el b/scala-mode2-fontlock.el
similarity index 99%
rename from scala-mode-fontlock.el
rename to scala-mode2-fontlock.el
index 6a96fe3..f7cda0e 100644
--- a/scala-mode-fontlock.el
+++ b/scala-mode2-fontlock.el
@@ -2,9 +2,9 @@
 ;;; Copyright (c) 2012 Heikki Vesalainen
 ;;; For information on the License, see the LICENSE file
 
-(provide 'scala-mode-fontlock)
+(provide 'scala-mode2-fontlock)
 
-(require 'scala-mode-syntax)
+(require 'scala-mode2-syntax)
 
 (defcustom scala-font-lock:constant-list '()
   "A list of strigs that should be fontified in constant
diff --git a/scala-mode-indent.el b/scala-mode2-indent.el
similarity index 99%
rename from scala-mode-indent.el
rename to scala-mode2-indent.el
index 8f05e3a..fafc079 100644
--- a/scala-mode-indent.el
+++ b/scala-mode2-indent.el
@@ -2,10 +2,10 @@
 ;;; Copyright (c) 2012 Heikki Vesalainen
 ;;; For information on the License, see the LICENSE file
 
-(provide 'scala-mode-indent)
+(provide 'scala-mode2-indent)
 
-(require 'scala-mode-syntax)
-(require 'scala-mode-lib)
+(require 'scala-mode2-syntax)
+(require 'scala-mode2-lib)
 
 (defcustom scala-indent:step 2
   "The number of spaces an indentation step should be. The actual
diff --git a/scala-mode-lib.el b/scala-mode2-lib.el
similarity index 96%
rename from scala-mode-lib.el
rename to scala-mode2-lib.el
index 2a0c932..1628280 100644
--- a/scala-mode-lib.el
+++ b/scala-mode2-lib.el
@@ -2,7 +2,7 @@
 ;;; Copyright (c) 2012 Heikki Vesalainen
 ;;; For information on the License, see the LICENSE file
 
-(provide 'scala-mode-lib)
+(provide 'scala-mode2-lib)
 
 (defvar scala-mode:debug-messages
   "If true, some debug messages may be printed printed."
diff --git a/scala-mode-map.el b/scala-mode2-map.el
similarity index 95%
rename from scala-mode-map.el
rename to scala-mode2-map.el
index 15e46a5..a7d4149 100644
--- a/scala-mode-map.el
+++ b/scala-mode2-map.el
@@ -2,9 +2,9 @@
 ;;; Copyright (c) 2012 Heikki Vesalainen
 ;;; For information on the License, see the LICENSE file
 
-(provide 'scala-mode-map)
+(provide 'scala-mode2-map)
 
-(require 'scala-mode-indent)
+(require 'scala-mode2-indent)
 
 (defmacro scala-mode-map:define-keys (key-map key-funcs)
   (cons 'progn (mapcar
diff --git a/scala-mode-paragraph.el b/scala-mode2-paragraph.el
similarity index 99%
rename from scala-mode-paragraph.el
rename to scala-mode2-paragraph.el
index f059eb3..060dcf9 100644
--- a/scala-mode-paragraph.el
+++ b/scala-mode2-paragraph.el
@@ -8,7 +8,7 @@
 ;;; Provides paragraph navigation and fill for scaladocs and
 ;;; multi-line strings.
 
-(provide 'scala-mode-paragraph)
+(provide 'scala-mode2-paragraph)
 
 (defconst scala-paragraph:paragraph-line-start-re
   (concat "\\(?:\\s *"                 ; whitespace
diff --git a/scala-mode2-pkg.el b/scala-mode2-pkg.el
new file mode 100644
index 0000000..6bc2b08
--- /dev/null
+++ b/scala-mode2-pkg.el
@@ -0,0 +1,2 @@
+(define-package "scala-mode2" "0.2"
+  "Major mode for editing Scala >= 2.9")
diff --git a/scala-mode-syntax.el b/scala-mode2-syntax.el
similarity index 99%
rename from scala-mode-syntax.el
rename to scala-mode2-syntax.el
index a4a8bb5..8a93206 100644
--- a/scala-mode-syntax.el
+++ b/scala-mode2-syntax.el
@@ -4,7 +4,7 @@
 
 ;;; Based on Scala Language Specification (SLS) Version 2.9
 
-(provide 'scala-mode-syntax)
+(provide 'scala-mode2-syntax)
 
 ;;;;
 ;;;; Scala syntax regular expressions
diff --git a/scala-mode.el b/scala-mode2.el
similarity index 83%
rename from scala-mode.el
rename to scala-mode2.el
index 81ff902..b85795a 100644
--- a/scala-mode.el
+++ b/scala-mode2.el
@@ -1,22 +1,23 @@
 ;;; scala-mode.el - Major mode for editing scala
 ;;; Copyright (c) 2012 Heikki Vesalainen
 ;;; For information on the License, see the LICENSE file
 
-;;; Based on Scala Language Specification (SLS) Version 2.9
+;; Copyright (c) 2012 Heikki Vesalainen
+;; For information on the License, see the LICENSE file
+;; URL: http://github.com/hvesalai/scala-mode2
+;; Based on Scala Language Specification (SLS) Version 2.9
 
-(provide 'scala-mode)
+(provide 'scala-mode2)
 
-(require 'scala-mode-lib)
-(require 'scala-mode-syntax)
-(require 'scala-mode-paragraph)
-(require 'scala-mode-indent)
-(require 'scala-mode-fontlock)
-(require 'scala-mode-map)
+(require 'scala-mode2-lib)
+(require 'scala-mode2-syntax)
+(require 'scala-mode2-paragraph)
+(require 'scala-mode2-indent)
+(require 'scala-mode2-fontlock)
+(require 'scala-mode2-map)
 
 ;; Tested only for emacs 24
 (unless (<= 24 emacs-major-version)
   (error
-   (format "The Scala mode has been tested only on Emacs version 24.2 (and not 
your Emacs version %s.%s)"
+   (format "The Scala mode has been tested only on Emacs version 24.2 (and not 
your Emacs version %s.%s)"  
            emacs-major-version  emacs-minor-version)))
 
 (defgroup scala nil
@@ -39,11 +40,11 @@
 (define-derived-mode scala-mode prog-mode "Scala"
   "Major mode for editing scala code.
 
-When started, runs `scala-mode-hook'.
+When started, runs `scala-mode-hook'. 
 
-\\{scala-mode-map}"
+\\{scala-mode-map}" 
   :syntax-table scala-syntax:syntax-table
-;  :group
+;  :group                               
 ;  :abbrev
 
   (scala-mode:make-local-variables
@@ -99,7 +100,6 @@ When started, runs `scala-mode-hook'.
   (turn-on-font-lock)
   ;; add indent functionality to some characters
   (scala-mode-map:add-self-insert-hooks)
-  (scala-mode-map:add-remove-indent-hook)
 )
 
 ;; Attach .scala files to the scala-mode
@@ -108,3 +108,5 @@ When started, runs `scala-mode-hook'.
 
 (add-to-list 'auto-mode-alist '("\\.scala\\'" . scala-mode))
 (modify-coding-system-alist 'file "\\.scala\\'" 'utf-8)
+
+;;; scala-mode2.el ends here
@@ -1,22 +1,23 @@
-;;; scala-mode.el - Major mode for editing scala
-;;; Copyright (c) 2012 Heikki Vesalainen
-;;; For information on the License, see the LICENSE file
+;;; scala-mode2.el --- Major mode for editing scala
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]